==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/theming/l10n/nl.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laden voorbeeld...",
    "Saved" : "Opgeslagen",
    "Admin" : "Beheer",
    "a safe home for all your data" : "een veilige plek voor al je gegevens",
    "The given name is too long" : "De opgegeven naam is te lang",
    "The given web address is too long" : "Het opgegeven internetadres is te lang",
    "The given slogan is too long" : "De opgegeven slagzin is te lang",
    "The given color is invalid" : "De opgegeven kleur is ongeldig",
    "There is no error, the file uploaded with success" : "Het bestand is succesvol geüpload.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Het geüploade bestand overschrijdt de upload_max_filesize richtlijn in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE richtlijn die is opgegeven in het HTML formulier",
    "The uploaded file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
    "Failed to write file to disk." : "Schrijven van het bestand naar schijf mislukte.",
    "A PHP extension stopped the file upload." : "Een PHP extensie heeft de upload gestopt.",
    "No file uploaded" : "Geen bestand geüpload",
    "Unsupported image type" : "Afbeeldingstype wordt niet ondersteund",
    "You are already using a custom theme" : "Je gebruikt al een maatwerkthema",
    "Theming" : "Thema's",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Thematiseren maakt het mogelijk om uiterlijk en gevoel van je systeem en ondersteunde clients aan te passen. Dit wordt zichtbaar voor alle gebruikers.",
    "Name" : "Naam",
    "Reset to default" : "Herstellen naar standaard",
    "Web address" : "Webadres",
    "Web address https://…" : "Webadres https://…",
    "Slogan" : "Slagzin",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nieuw logo",
    "Login image" : "Inlog afbeelding",
    "Upload new login background" : "Uploaden nieuwe inlog achtergrond",
    "Remove background image" : "Achtergrond beeld verwijderen",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installeer de Imagemagick PHP extensie met ondersteuning voor SVG afbeeldingen om automatisch favicons te genereren op basis van het geuploade logo en kleur.",
    "reset to default" : "herstellen naar standaard",
    "Log in image" : "Inlog afbeelding"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/theming/l10n/nl.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laden voorbeeld...",
    "Saved" : "Opgeslagen",
    "Admin" : "Beheer",
    "a safe home for all your data" : "een veilige plek voor al je gegevens",
    "The given name is too long" : "De opgegeven naam is te lang",
    "The given web address is too long" : "Het opgegeven internetadres is te lang",
    "The given slogan is too long" : "De opgegeven slagzin is te lang",
    "The given color is invalid" : "De opgegeven kleur is ongeldig",
    "There is no error, the file uploaded with success" : "Er trad geen fout op, het bestand is succesvol geüpload",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Het geüploade bestand overschrijdt de upload_max_filesize richtlijn in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE richtlijn die is opgegeven in het HTML formulier",
    "The uploaded file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
    "Failed to write file to disk." : "Schrijven van het bestand naar schijf mislukte.",
    "A PHP extension stopped the file upload." : "Een PHP extensie heeft de upload gestopt.",
    "No file uploaded" : "Geen bestand geüpload",
    "Unsupported image type" : "Afbeeldingstype wordt niet ondersteund",
    "You are already using a custom theme" : "Je gebruikt al een maatwerkthema",
    "Theming" : "Thema's",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Thematiseren maakt het mogelijk om uiterlijk en gevoel van je systeem en ondersteunde clients aan te passen. Dit wordt zichtbaar voor alle gebruikers.",
    "Name" : "Naam",
    "Reset to default" : "Herstellen naar standaard",
    "Web address" : "Webadres",
    "Web address https://…" : "Webadres https://…",
    "Slogan" : "Slagzin",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nieuw logo",
    "Login image" : "Inlog afbeelding",
    "Upload new login background" : "Uploaden nieuwe inlog achtergrond",
    "Remove background image" : "Achtergrond beeld verwijderen",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installeer de Imagemagick PHP extensie met ondersteuning voor SVG afbeeldingen om automatisch favicons te genereren op basis van het geuploade logo en kleur.",
    "reset to default" : "herstellen naar standaard",
    "Log in image" : "Inlog afbeelding"
},
"nplurals=2; plural=(n != 1);");
